Moteur de recherche interne - casimages.com
Author: Casimages.com
Description: Rechercher des fichiers ou des images dans le gestionnaire
Keywords: Manager Casimages

Sergeileduc Offre Decouverte

## moteur de recherche

Rechercher dans :
Images
Fichiers

Affichage des 2 résultats

SELECT

##### sample image.png

17-03-2021 | 125x125 12 Ko
SELECT

##### sample image.png

17-03-2021 | 125x125 12 Ko
P 1 |

## Changer le nom de l'image

Nouveau nom de l'image

## Déplacer l'image

Séléctionnez le dossier de destination :

## Partager l'image

## Propriétés de l'image

## Supprimer l'image

#### ATTENTION

Confirmez-vous la suppression de l'image ?

## Changer le nom du fichier

Nouveau nom du fichier

## Déplacer le fichier

Séléctionnez le dossier de destination :

## Codes de partage du fichier

## Propriétés du fichier

## Supprimer le fichier

#### ATTENTION

Confirmez-vous la suppression du fichier ?